@@ -18,7 +18,7 @@ distr_vonmises_meanconc_density <- function(y, f) {
   t <- nrow(f)
   m <- f[, 1, drop = FALSE]
   v <- f[, 2, drop = FALSE]
-  res_density <- be_silent(CircStats::dvm(y, mu = m, kappa = v))
+  res_density <- exp(v * cos(y - m)) / (2 * pi * besselI(v, nu = 0))
   return(res_density)
 }
 # ------------------------------------------------------------------------------
@@ -29,7 +29,7 @@ distr_vonmises_meanconc_loglik <- function(y, f) {
   t <- nrow(f)
   m <- f[, 1, drop = FALSE]
   v <- f[, 2, drop = FALSE]
-  res_loglik <- be_silent(log(CircStats::dvm(y, mu = m, kappa = v)))
+  res_loglik <- v * cos(y - m) - log(2 * pi * besselI(v, nu = 0))
   return(res_loglik)
 }
 # ------------------------------------------------------------------------------
@@ -88,8 +88,26 @@ distr_vonmises_meanconc_fisher <- function(f) {
 distr_vonmises_meanconc_random <- function(t, f) {
   m <- f[1]
   v <- f[2]
-  res_random <- be_silent(CircStats::rvm(t, mean = m, k = v))
-  res_random <- matrix(res_random, nrow = t, ncol = 1L)
+  res_random <- matrix(NA, nrow = t, ncol = 1L)
+  a <- 1 + sqrt(1 + 4 * v^2)
+  b <- (a - sqrt(2 * a)) / (2 * v)
+  r <- (1 + b^2) / (2 * b)
+  for (i in 1:t) {
+    repeat {
+      u1 <- stats::runif(1)
+      z <- cos(pi * u1)
+      f <- (1 + r * z) / (r + z)
+      c <- v * (r - f)
+      u2 <- stats::runif(1)
+      if (u2 < c * (2 - c) || log(c / u2) + 1 - c >= 0) {
+        u3 <- stats::runif(1)
+        sign <- ifelse(u3 > 0.5, 1, -1)
+        theta <- m + sign * acos(f)
+        res_random[i, 1] <- theta %% (2 * pi)
+        break()
+      }
+    }
+  }
   return(res_random)
 }
 # ------------------------------------------------------------------------------
@@ -97,9 +115,17 @@ distr_vonmises_meanconc_random <- function(t, f) {
 
 # Starting Estimates Function --------------------------------------------------
 distr_vonmises_meanconc_start <- function(y) {
-  ml_est <- CircStats::vm.ml(y)
-  m <- ml_est[1, 1] + (2 * pi) * (ml_est[1, 1] < 0)
-  v <- ml_est[1, 2]
+  c <- mean(cos(y))
+  s <- mean(sin(y))
+  m <- atan2(s, c) %% (2 * pi)
+  r <- sqrt(c^2 + s^2)
+  if (r < 0.53) {
+    v <- 2 * r + r^3 + (5 * r^5) / 6
+  } else if (r < 0.85) {
+    v <- -0.4 + 1.39 * r + 0.43 / (1 - r)
+  } else {
+    v <- 1 / (r^3 - 4 * r^2 + 3 * r)
+  }
   res_start <- c(m, v)
   return(res_start)
 }
